pycbc_inference \
--config-file `dirname "$0"`/single_simple.ini \
--nprocesses=2 \
--output-file single.hdf \
--seed 0 \
--force \
--verbose
